@@ -87,8 +87,13 @@ static int isSpecFile(const char * specfile)
 	    /*@switchbreak@*/ break;
 /*@-boundsread@*/
 	default:
+#if 0
 	    if (checking && !(isprint(*s) || isspace(*s))) return 0;
 	    /*@switchbreak@*/ break;
+#else
+	    if (checking && !(isprint(*s) || isspace(*s)) && *(unsigned char *)s < 32) return 0;
+	    /*@switchbreak@*/ break;
+#endif
 /*@=boundsread@*/
 	}
     }
@@ -156,7 +161,7 @@ static int buildForTarget(rpmts ts, const char * arg, BTA_t ba)
 	    /* Try again */
 	    (void) pclose(fp);
 
-	    sprintf(cmd, "%s < %s | tar xOvf - \\*.spec 2>&1 > %s",
+	    sprintf(cmd, "%s < %s | tar xOvf - --wildcards \\*.spec 2>&1 > %s",
 		    zcmds[res & 0x3], arg, tmpSpecFile);
 	    if (!(fp = popen(cmd, "r"))) {
 		rpmError(RPMERR_POPEN, _("Failed to open tar pipe: %m\n"));
@@ -206,7 +211,10 @@ static int buildForTarget(rpmts ts, const char * arg, BTA_t ba)
 	   directory for this run */
 
 	if (*arg != '/') {
-	    (void)getcwd(buf, BUFSIZ);
+	    if (!getcwd(buf, BUFSIZ)) {
+		rpmError(RPMERR_STAT, "getcwd failed: %m\n");
+		return 1;
+	    }
 	    strcat(buf, "/");
 	    strcat(buf, arg);
 	} else 
@@ -225,7 +233,11 @@ static int buildForTarget(rpmts ts, const char * arg, BTA_t ba)
     specut = urlPath(specURL, &specFile);
     if (*specFile != '/') {
 	char *s = alloca(BUFSIZ);
-	(void)getcwd(s, BUFSIZ);
+	if (!getcwd(s, BUFSIZ)) {
+	    rpmError(RPMERR_STAT, "getcwd failed: %m\n");
+	    rc = 1;
+	    goto exit;
+	}
 	strcat(s, "/");
 	strcat(s, arg);
 	specURL = s;
