@@ -214,8 +214,8 @@ int rpmtsAddInstallElement(rpmts ts, Header h,
 		    _("package %s was already added, skipping %s\n"),
 		    (pkgNEVR ? pkgNEVR + 2 : "?pkgNEVR?"),
 		    (addNEVR ? addNEVR + 2 : "?addNEVR?"));
-	    ec = 1;
-	    break;
+	    ec = 0;
+	    goto exit;
 	}
 
 	/*
@@ -1160,7 +1160,8 @@ static int orderListIndexCmp(const void * one, const void * two)	/*@*/
 /*@-mustmod@*/
 static void addQ(/*@dependent@*/ rpmte p,
 		/*@in@*/ /*@out@*/ rpmte * qp,
-		/*@in@*/ /*@out@*/ rpmte * rp)
+		/*@in@*/ /*@out@*/ rpmte * rp,
+		uint_32 prefcolor)
 	/*@modifies p, *qp, *rp @*/
 {
     rpmte q, qprev;
@@ -1180,6 +1181,10 @@ static void addQ(/*@dependent@*/ rpmte p,
 	 q != NULL;
 	 qprev = q, q = rpmteTSI(q)->tsi_suc)
     {
+	/* XXX Insure preferred color first. */
+	if (rpmteColor(p) != prefcolor && rpmteColor(p) != rpmteColor(q))
+	    continue;
+
 	if (rpmteTSI(q)->tsi_qcnt <= rpmteTSI(p)->tsi_qcnt)
 	    break;
     }
@@ -1208,6 +1213,7 @@ int rpmtsOrder(rpmts ts)
     rpmds requires;
     int_32 Flags;
     int anaconda = rpmtsFlags(ts) & RPMTRANS_FLAG_ANACONDA;
+    uint_32 prefcolor = rpmtsPrefColor(ts);
     rpmtsi pi; rpmte p;
     rpmtsi qi; rpmte q;
     rpmtsi ri; rpmte r;
@@ -1370,7 +1376,7 @@ rescan:
 	if (rpmteTSI(p)->tsi_count != 0)
 	    continue;
 	rpmteTSI(p)->tsi_suc = NULL;
-	addQ(p, &q, &r);
+	addQ(p, &q, &r, prefcolor);
 	qlen++;
     }
     pi = rpmtsiFree(pi);
@@ -1441,7 +1447,7 @@ rescan:
 
 		/* XXX TODO: add control bit. */
 		rpmteTSI(p)->tsi_suc = NULL;
-		addQ(p, &rpmteTSI(q)->tsi_suc, &r);
+		addQ(p, &rpmteTSI(q)->tsi_suc, &r, prefcolor);
 		qlen++;
 	    }
 	    tsi = _free(tsi);
