@@ -454,11 +454,16 @@ static /*@observer@*/ const char * const tag2sln(int tag)
 	/*@*/
 {
     switch (tag) {
-    case RPMTAG_PREIN:		return "%pre";
-    case RPMTAG_POSTIN:		return "%post";
-    case RPMTAG_PREUN:		return "%preun";
-    case RPMTAG_POSTUN:		return "%postun";
-    case RPMTAG_VERIFYSCRIPT:	return "%verify";
+    case RPMTAG_PRETRANS:       return "%pretrans";
+    case RPMTAG_PREIN:          return "%pre";
+    case RPMTAG_POSTIN:         return "%post";
+    case RPMTAG_TRIGGERIN:      return "%triggerin";
+    case RPMTAG_TRIGGERUN:      return "%triggerun";
+    case RPMTAG_PREUN:          return "%preun";
+    case RPMTAG_POSTUN:         return "%postun";
+    case RPMTAG_POSTTRANS:      return "%posttrans";
+    case RPMTAG_TRIGGERPOSTUN:  return "%triggerpostun";
+    case RPMTAG_VERIFYSCRIPT:   return "%verify";
     }
     return "%unknownscript";
 }
@@ -1747,7 +1752,14 @@ psm->te->h = headerLink(fi->h);
 
 	    if (rpmtsFlags(ts) & RPMTRANS_FLAG_JUSTDB)	break;
 	    if (rpmtsFlags(ts) & RPMTRANS_FLAG_APPLYONLY)	break;
-	    if (fc <= 0)				break;
+
+	    /* XXX Synthesize callbacks for packages with no files. */
+	    if (rpmfiFC(fi) <= 0) {
+		void * ptr;
+		ptr = rpmtsNotify(ts, fi->te, RPMCALLBACK_UNINST_START, 0, 100);
+		ptr = rpmtsNotify(ts, fi->te, RPMCALLBACK_UNINST_STOP, 0, 100);
+		break;
+	    }
 
 	    psm->what = RPMCALLBACK_UNINST_START;
 	    psm->amount = fc;		/* XXX W2DO? looks wrong. */
