@@ -599,6 +599,10 @@ if (fileURL[0] == '=') {
 	    eiu->numFailed++;
 	    goto exit;
 	    /*@notreached@*/ /*@switchbreak@*/ break;
+	default:
+	    eiu->numFailed++;
+	    goto exit;
+	    /*@notreached@*/ /*@switchbreak@*/ break;
 	}
 
 	eiu->numRPMS++;
@@ -835,22 +839,20 @@ int rpmErase(rpmts ts, struct rpmInstallArguments_s * ia,
 	ps = rpmpsFree(ps);
     }
 
-#ifdef	NOTYET
     if (!stopUninstall && !(ia->installInterfaceFlags & INSTALL_NOORDER)) {
 	if (rpmtsOrder(ts)) {
 	    numFailed += numPackages;
 	    stopUninstall = 1;
 	}
     }
-#endif
 
-    if (!stopUninstall) {
+    if (numPackages && !stopUninstall) {
 	(void) rpmtsSetFlags(ts, (rpmtsFlags(ts) | RPMTRANS_FLAG_REVERSE));
 
 	/* Drop added/available package indices and dependency sets. */
 	rpmtsClean(ts);
 
-	numPackages = rpmtsRun(ts, NULL, 0);
+	numPackages = rpmtsRun(ts, NULL, ia->probFilter & (RPMPROB_FILTER_DISKSPACE|RPMPROB_FILTER_DISKNODES));
 	ps = rpmtsProblems(ts);
 	if (rpmpsNumProblems(ps) > 0)
 	    rpmpsPrint(NULL, ps);
