@@ -7,6 +7,7 @@
 #include <rpmio_internal.h>
 #include <rpmcli.h>	/* XXX for rpmCheckSig */
 #include <rpmdb.h>
+#include <rpmsq.h>
 
 #include "legacy.h"
 #include "misc.h"
@@ -41,6 +42,18 @@
  */
 PyObject * pyrpmError;
 
+/**
+ */
+static PyObject * expandMacro(PyObject * self, PyObject * args, PyObject * kwds)
+{
+    char * macro;
+
+    if (!PyArg_ParseTuple(args, "s", &macro))
+	return NULL;
+
+    return Py_BuildValue("s", rpmExpand(macro, NULL));
+}
+
 /**
  */
 static PyObject * archScore(PyObject * self, PyObject * args, PyObject * kwds)
@@ -57,6 +70,50 @@ static PyObject * archScore(PyObject * self, PyObject * args, PyObject * kwds)
     return Py_BuildValue("i", score);
 }
 
+/**
+ *  */
+static PyObject * signalsCaught(PyObject * self, PyObject * check)
+{
+    PyObject *caught, *o;
+    int llen;
+    int signum, i;
+    sigset_t newMask, oldMask;
+
+    if (!PyList_Check(check)) {
+	PyErr_SetString(PyExc_TypeError, "list expected");
+	return NULL;
+    }
+
+    llen = PyList_Size(check);
+    caught = PyList_New(0);
+
+    /* block signals while checking for them */
+    (void) sigfillset(&newMask);
+    (void) sigprocmask(SIG_BLOCK, &newMask, &oldMask);
+
+    for (i = 0; i < llen; i++) {
+	o = PyList_GetItem(check, i);
+	signum = PyInt_AsLong(o);
+	if (sigismember(&rpmsqCaught, signum)) {
+	    PyList_Append(caught, o);
+	}
+    }
+    (void) sigprocmask(SIG_SETMASK, &oldMask, NULL);
+
+    return caught;
+}
+
+/**
+ *  */
+static PyObject * checkSignals(PyObject * self, PyObject * args)
+{
+    if (!PyArg_ParseTuple(args, ":checkSignals")) return NULL;
+    rpmdbCheckSignals();
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
+
 /**
  */
 static PyObject * setLogFile (PyObject * self, PyObject * args, PyObject *kwds)
@@ -142,10 +199,17 @@ static PyMethodDef rpmModuleMethods[] = {
 	NULL },
     { "delMacro", (PyCFunction) rpmrc_DelMacro, METH_VARARGS|METH_KEYWORDS,
 	NULL },
+    { "expandMacro", (PyCFunction) expandMacro, METH_VARARGS|METH_KEYWORDS,
+	NULL },
 
     { "archscore", (PyCFunction) archScore, METH_VARARGS|METH_KEYWORDS,
 	NULL },
 
+    { "signalsCaught", (PyCFunction) signalsCaught, METH_O, 
+	NULL },
+    { "checkSignals", (PyCFunction) checkSignals, METH_VARARGS,
+        NULL },
+
     { "headerLoad", (PyCFunction) hdrLoad, METH_VARARGS|METH_KEYWORDS,
 	NULL },
     { "rhnLoad", (PyCFunction) rhnLoad, METH_VARARGS|METH_KEYWORDS,
@@ -179,6 +243,14 @@ static PyMethodDef rpmModuleMethods[] = {
     { NULL }
 } ;
 
+/*
+* Force clean up of open iterators and dbs on exit.
+*/
+static void rpm_exithook(void)
+{
+   rpmdbCheckTerminate(1);
+}
+
 /**
  */
 static char rpm__doc__[] =
@@ -217,6 +289,13 @@ void init_rpm(void)
     if (m == NULL)
 	return;
 
+    /* 
+     * treat error to register rpm cleanup hook as fatal, tracebacks
+     * can and will leave stale locks around if we can't clean up
+     */
+    if (Py_AtExit(rpm_exithook) == -1)
+	return;
+
     rpmReadConfigFiles(NULL, NULL);
 
     d = PyModule_GetDict(m);
