@@ -253,7 +253,7 @@ findEntry(MacroContext mc, const char * name, size_t namelen)
 {
     MacroEntry key, *ret;
     struct MacroEntry_s keybuf;
-    char namebuf[1024];
+    char *namebuf = NULL;
 
 /*@-globs@*/
     if (mc == NULL) mc = rpmGlobalMacroContext;
@@ -263,6 +263,8 @@ findEntry(MacroContext mc, const char * name, size_t namelen)
 
 /*@-branchstate@*/
     if (namelen > 0) {
+	namebuf = alloca(namelen + 1);
+	memset(namebuf, 0, (namelen + 1));
 	strncpy(namebuf, name, namelen);
 	namebuf[namelen] = '\0';
 	name = namebuf;
@@ -602,6 +604,11 @@ doShellEscape(MacroBuf mb, const char * cmd, size_t clen)
     int rc;
     int c;
 
+    if (clen >= sizeof(pcmd)) {
+	rpmError(RPMERR_BADSPEC, _("Target buffer overflow\n"));
+	return 1;
+    }
+
     strncpy(pcmd, cmd, clen);
     pcmd[clen] = '\0';
     rc = expandU(mb, pcmd, sizeof(pcmd));
@@ -1079,6 +1086,10 @@ doOutput(MacroBuf mb, int waserror, const char * msg, size_t msglen)
 {
     char buf[BUFSIZ];
 
+    if (msglen >= sizeof(buf)) {
+	rpmError(RPMERR_BADSPEC, _("Target buffer overflow\n"));
+	msglen = sizeof(buf) - 1;
+    }
     strncpy(buf, msg, msglen);
     buf[msglen] = '\0';
     (void) expandU(mb, buf, sizeof(buf));
@@ -1108,6 +1119,10 @@ doFoo(MacroBuf mb, int negate, const char * f, size_t fn,
 
     buf[0] = '\0';
     if (g != NULL) {
+	if (gn >= sizeof(buf)) {
+	    rpmError(RPMERR_BADSPEC, _("Target buffer overflow\n"));
+	    gn = sizeof(buf) - 1;
+        }
 	strncpy(buf, g, gn);
 	buf[gn] = '\0';
 	(void) expandU(mb, buf, sizeof(buf));
@@ -1999,6 +2014,11 @@ rpmInitMacros(MacroContext mc, const char * macrofiles)
 
 	/* Read macros from each file. */
 	for (i = 0; i < ac; i++) {
+	    if (strstr(av[i], ".rpmnew") || 
+		strstr(av[i], ".rpmsave") ||
+		strstr(av[i], ".rpmorig")) {
+		continue;
+	    }
 	    (void) rpmLoadMacroFile(mc, av[i]);
 	    av[i] = _free(av[i]);
 	}
