@@ -637,7 +637,7 @@ int ufdGetFile( /*@killref@*/ FD_t sfd, FD_t tfd)
 /*@unused@*/ int timedRead(FD_t fd, /*@out@*/ void * bufptr, int length)
 	/*@globals fileSystem @*/
 	/*@modifies fd, *bufptr, fileSystem @*/;
-#define	timedRead	ufdio->read
+#define	timedRead	(ufdio->read)
 
 /*@-exportlocal@*/
 /**
